@@ -1,4 +1,4 @@
-from typing import List
+from typing import List, Type
 
 from sanic import json
 from sanic.exceptions import NotFound
@@ -11,7 +11,8 @@ from web_foundation.workers.io.http.chaining import InputContext
 
 async def exec_access(inc: InputContext,
                       model: AbstractDbModel,
-                      fetch_fields: List[str] = None
+                      fetch_fields: List[str] = None,
+                      middleware: Type[AccessDMW] = AccessDMW
                       ):
     """
     Access to models
@@ -42,11 +43,11 @@ async def exec_access(inc: InputContext,
                         val = py_json.loads(val)
                     kwargs[ar] = val
 
-                retrieved_all, total = await AccessDMW.read_all(model, inc.identity, limit, offset,
+                retrieved_all, total = await middleware.read_all(model, inc.identity, limit, offset,
                                                                 fetch_fields=fetch_fields, **kwargs)
                 res = [await model.values_dict() for model in retrieved_all]
                 return res
-            retrieved = await AccessDMW.read(model, entity_id, inc.identity, fetch_fields=fetch_fields, **kwargs)
+            retrieved = await middleware.read(model, entity_id, inc.identity, fetch_fields=fetch_fields, **kwargs)
             if retrieved:
                 result = await retrieved.values_dict()
                 return result
@@ -55,7 +56,7 @@ async def exec_access(inc: InputContext,
 
         case "POST":
             assert inc.dto
-            retrieved = await AccessDMW.create(model, inc.identity, inc.dto, **inc.r_kwargs)
+            retrieved = await middleware.create(model, inc.identity, inc.dto, **inc.r_kwargs)
             if isinstance(retrieved, list):
                 return [await i.values_dict() for i in retrieved]
             return await retrieved.values_dict()
@@ -64,11 +65,11 @@ async def exec_access(inc: InputContext,
             assert inc.dto
             entity_id = inc.r_kwargs.pop("entity_id")
             assert entity_id
-            retrieved = await AccessDMW.update(model, entity_id, inc.identity, inc.dto, **inc.r_kwargs)
+            retrieved = await middleware.update(model, entity_id, inc.identity, inc.dto, **inc.r_kwargs)
             return await retrieved.values_dict()
 
         case "DELETE":
             entity_id = inc.r_kwargs.pop("entity_id")
             assert entity_id
-            retrieved = await AccessDMW.delete(model, entity_id, inc.identity, **inc.r_kwargs)
-            return await retrieved.values_dict()
\ No newline at end of file
+            retrieved = await middleware.delete(model, entity_id, inc.identity, **inc.r_kwargs)
+            return await retrieved.values_dict()
