@@ -67,12 +67,14 @@ def add_openapi_spec(uri: str, method_name: str, func: Callable, handler: Callab
 class DictRouter(ExtRouter):
     _router_conf: Dict
     chaining: Callable
+    versioning: bool
 
-    def __init__(self, routes_config: Dict, chaining: Callable):
+    def __init__(self, routes_config: Dict, chaining: Callable, versioning: bool = True):
         super().__init__()
         self.chaining = chaining
         self._router_conf = routes_config
         self.chains = []
+        self.versioning = versioning
 
     def apply_routes(self, app: Sanic, **kwargs):
         """
@@ -108,8 +110,11 @@ class DictRouter(ExtRouter):
                                                              ))
                         chain = add_openapi_spec(uri=endpoint, method_name=method_name, func=target_func,
                                                  handler=chain, in_dto=in_dto, out_dto=out_dto)
-                        app.add_route(uri=endpoint, methods={method_name.upper()}, handler=chain,
-                                      version_prefix=version_prefix, version=version)
+                        if self.versioning:
+                            app.add_route(uri=endpoint, methods={method_name.upper()}, handler=chain,
+                                          version_prefix=version_prefix, version=version)
+                        else:
+                            app.add_route(uri=endpoint, methods={method_name.upper()}, handler=chain)
 
                     route = RouteConf(app_name=app_route.get("app_name"), path=endpoint, methods=methods_confs)
                     self.chains.append(route)
