@@ -55,7 +55,8 @@ class HttpServer(Worker):
         }
 
     async def _run(self):
-        await self._init_resources()
+        # await self._init_resources()
+        self.sanic_app.register_listener(self._init_resources, "before_server_start")
         # noinspection PyAsyncCall
         self.sanic_app.add_task(self.channel.listen_consume())
 
